@@ -1,33 +1,29 @@
-from __future__ import absolute_import, division
+from sys import stdout
+from typing import cast
+from unittest.mock import Mock, patch
 
-import sys
-
-try:
-    from unittest.mock import Mock, patch
-except Exception:
-    from mock import Mock, patch  # type:ignore[misc]
+from zope.interface import implementer
 
 from twisted.python.components import registerAdapter
 from twisted.trial import unittest
+from twisted.web.iweb import IRequest
 
-from .test_resource import requestMock
-from .util import EqualityTestsMixin
 from .. import Klein
 from .._app import KleinRequest
 from .._decorators import bindable, modified, originalName
 from .._interfaces import IKleinRequest
+from .test_resource import MockRequest
+from .util import EqualityTestsMixin
 
 
-class DummyRequest(object):
+@implementer(IRequest)
+class DummyRequest:  # type: ignore[misc]  # incomplete interface
     def __init__(self, n):
         self.n = n
 
     def __eq__(self, other):
         return other.n == self.n
 
-    def __repr__(self):
-        return "<DummyRequest({n})>".format(n=self.n)
-
 
 registerAdapter(KleinRequest, DummyRequest, IKleinRequest)
 
@@ -37,7 +33,7 @@ class KleinEqualityTestCase(unittest.TestCase, EqualityTestsMixin):
     Tests for L{Klein}'s implementation of C{==} and C{!=}.
     """
 
-    class _One(object):
+    class _One:
         app = Klein()
 
         def __eq__(self, other):
@@ -63,7 +59,7 @@ class KleinEqualityTestCase(unittest.TestCase, EqualityTestsMixin):
         return self._another
 
 
-class DuplicateHasher(object):
+class DuplicateHasher:
     """
     Every L{DuplicateHasher} has the same hash value and compares equal to
     every other L{DuplicateHasher}.
@@ -155,7 +151,7 @@ class KleinTestCase(unittest.TestCase):
         identity.
         """
 
-        class Wrap(object):
+        class Wrap:
             def __init__(self, wrapped):
                 self._wrapped = wrapped
 
@@ -164,7 +160,7 @@ class KleinTestCase(unittest.TestCase):
                     return self
                 return self._wrapped.__get__(instance, owner)
 
-        class TwoRouters(object):
+        class TwoRouters:
 
             app1 = Wrap(Klein())
             app2 = Wrap(Klein())
@@ -180,13 +176,13 @@ class KleinTestCase(unittest.TestCase):
         searching for the bound L{Klein} instance.
         """
 
-        class ClassProperty(object):
+        class ClassProperty:
             def __get__(self, oself, owner):
                 raise AttributeError(
                     "you just don't have that special something"
                 )
 
-        class Oddment(object):
+        class Oddment:
             __something__ = ClassProperty()
             app = Klein()
 
@@ -252,11 +248,13 @@ class KleinTestCase(unittest.TestCase):
         )
 
         self.assertEquals(
-            app.endpoints["branchfunc"].__name__,
+            app.endpoints["branchfunc"].__name__,  # type: ignore[union-attr]
             "route '/foo/' executor for branchfunc",
         )
         self.assertEquals(
-            app.endpoints["branchfunc_branch"].__name__,
+            app.endpoints[
+                "branchfunc_branch"
+            ].__name__,  # type: ignore[union-attr]
             "branch route '/foo/' executor for branchfunc",
         )
         self.assertEquals(
@@ -281,10 +279,10 @@ class KleinTestCase(unittest.TestCase):
             calls.append(args)
             return 7
 
-        req = object()
+        req = cast(IRequest, object())
         k.execute_endpoint("method", req)
 
-        class BoundTo(object):
+        class BoundTo:
             app = k
 
         b = BoundTo()
@@ -311,7 +309,7 @@ class KleinTestCase(unittest.TestCase):
             return add(a * 1000, b * 10000)
 
         self.assertEqual(megaAdd.supersized, True)
-        self.assertEqual(add.supersized, True)
+        self.assertEqual(add.supersized, True)  # type: ignore[attr-defined]
         self.assertIn("supersizer for add", str(megaAdd))
         self.assertEqual(megaAdd(3, 4), 43000)
 
@@ -322,7 +320,7 @@ class KleinTestCase(unittest.TestCase):
         """
         bar_calls = []
 
-        class Foo(object):
+        class Foo:
             app = Klein()
 
             @app.route("/bar")
@@ -346,7 +344,7 @@ class KleinTestCase(unittest.TestCase):
         independently.
         """
 
-        class Foo(object):
+        class Foo:
             app = Klein()
 
             def __init__(self):
@@ -378,7 +376,7 @@ class KleinTestCase(unittest.TestCase):
         independently.
         """
 
-        class Foo(object):
+        class Foo:
             app = Klein()
 
             def __init__(self):
@@ -442,7 +440,7 @@ class KleinTestCase(unittest.TestCase):
 
         mock_site.assert_called_with(mock_kr.return_value)
         mock_kr.assert_called_with(app)
-        mock_log.startLogging.assert_called_with(sys.stdout)
+        mock_log.startLogging.assert_called_with(stdout)
 
     @patch("klein._app.KleinResource")
     @patch("klein._app.Site")
@@ -469,7 +467,7 @@ class KleinTestCase(unittest.TestCase):
 
     @patch("klein._app.KleinResource")
     @patch("klein._app.log")
-    @patch("klein._app.endpoints.serverFromString")
+    @patch("klein._app.serverFromString")
     @patch("klein._app.reactor")
     def test_runTCP6(self, reactor, mock_sfs, mock_log, mock_kr):
         """
@@ -477,16 +475,16 @@ class KleinTestCase(unittest.TestCase):
         """
         app = Klein()
         interface = "2001\\:0DB8\\:f00e\\:eb00\\:\\:1"
-        spec = "tcp6:8080:interface={0}".format(interface)
+        spec = f"tcp6:8080:interface={interface}"
         app.run(endpoint_description=spec)
         reactor.run.assert_called_with()
         mock_sfs.assert_called_with(reactor, spec)
-        mock_log.startLogging.assert_called_with(sys.stdout)
+        mock_log.startLogging.assert_called_with(stdout)
         mock_kr.assert_called_with(app)
 
     @patch("klein._app.KleinResource")
     @patch("klein._app.log")
-    @patch("klein._app.endpoints.serverFromString")
+    @patch("klein._app.serverFromString")
     @patch("klein._app.reactor")
     def test_runSSL(self, reactor, mock_sfs, mock_log, mock_kr):
         """
@@ -501,7 +499,7 @@ class KleinTestCase(unittest.TestCase):
         app.run(endpoint_description=spec)
         reactor.run.assert_called_with()
         mock_sfs.assert_called_with(reactor, spec)
-        mock_log.startLogging.assert_called_with(sys.stdout)
+        mock_log.startLogging.assert_called_with(stdout)
         mock_kr.assert_called_with(app)
 
     @patch("klein._app.KleinResource")
@@ -528,20 +526,20 @@ class KleinTestCase(unittest.TestCase):
         def foo(req, postid):
             return str(postid)
 
-        request = requestMock(b"/user/john")
+        request = MockRequest(b"/user/john")
         self.assertEqual(
             app.execute_endpoint("userpage", request, "john"), "john"
         )
         self.assertEqual(
-            app.execute_endpoint("bar", requestMock(b"/post/123"), 123), "123"
+            app.execute_endpoint("bar", MockRequest(b"/post/123"), 123), "123"
         )
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         self.assertEqual(
             app.urlFor(request, "userpage", {"name": "john"}), "/user/john"
         )
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         self.assertEqual(
             app.urlFor(
                 request, "userpage", {"name": "john"}, force_external=True
@@ -549,7 +547,7 @@ class KleinTestCase(unittest.TestCase):
             "http://localhost:8080/user/john",
         )
 
-        request = requestMock(b"/addr", host=b"example.com", port=4321)
+        request = MockRequest(b"/addr", host=b"example.com", port=4321)
         self.assertEqual(
             app.urlFor(
                 request, "userpage", {"name": "john"}, force_external=True
@@ -557,7 +555,7 @@ class KleinTestCase(unittest.TestCase):
             "http://example.com:4321/user/john",
         )
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         url = app.urlFor(
             request,
             "userpage",
@@ -566,18 +564,18 @@ class KleinTestCase(unittest.TestCase):
         )
         self.assertEqual(url, "/user/john?age=29")
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         self.assertEqual(
             app.urlFor(request, "bar", {"postid": 123}), "/post/123"
         )
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         request.requestHeaders.removeHeader(b"host")
         self.assertEqual(
             app.urlFor(request, "bar", {"postid": 123}), "/post/123"
         )
 
-        request = requestMock(b"/addr")
+        request = MockRequest(b"/addr")
         request.requestHeaders.removeHeader(b"host")
         with self.assertRaises(ValueError):
             app.urlFor(request, "bar", {"postid": 123}, force_external=True)
